"use client";

import React, { useState } from "react";
import PricingHeader from "@/components/pricing/pricing-header";
import PricingSwitch from "@/components/pricing/pricing-switch";
import PricingCard from "@/components/pricing/pricing-card";

export default function Page() {
  const [isYearly, setIsYearly] = useState(false);
  const togglePricingPeriod = (value: string) =>
    setIsYearly(parseInt(value) === 1);

  const plans = [
    {
      title: "Basic",
      monthlyPrice: 10,
      yearlyPrice: 100,
      description: "Essential features you need to get started",
      features: [
        "Full access to our extensive library of courses and tutorials",
        "Regularly updated content to keep you ahead of the curve",
        "Skill assessments and progress tracking",
        "Community forums for networking and support",
        "Certificate of completion for each course",
      ],
      actionLabel: "Get Started",
    },
    {
      title: "Pro",
      monthlyPrice: 25,
      yearlyPrice: 250,
      description: "Perfect for owners of small & medium businessess",
      features: [
        "All features included in the Basic tier",
        "Exclusive access to advanced courses and workshops",
        "Personalized career coaching sessions",
        "Priority customer support",
        "Premium resources such as e-books and industry reports",
      ],
      actionLabel: "Get Started",
      popular: true,
    },
    {
      title: "Enterprise",
      price: "Custom",
      description: "Dedicated support and infrastructure to fit your needs",
      features: [
        "Tailored solutions for businesses and teams",
        "Dedicated account management",
        "Customizable learning paths and content curation",
        "Team analytics and progress tracking",
        "On-site workshops and training sessions (optional)",
      ],
      actionLabel: "Contact Sales",
      exclusive: true,
    },
  ];
  return (
    <div className="py-8 md:py-24">
      <PricingHeader
        title="Welcome to Skilld Pricing"
        subtitle="At Skilld, we empower software engineers with top-notch upskilling resources tailored to their career goals. Explore our pricing plans below and take the next step towards mastering your craft."
      />
      <PricingSwitch onSwitch={togglePricingPeriod} />
      <section className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 justify-center gap-8 mt-8">
        {plans.map((plan) => {
          return <PricingCard key={plan.title} {...plan} isYearly={isYearly} />;
        })}
      </section>
    </div>
  );
}
